@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -70,6 +70,7 @@ static struct argp_option cmdline_options[] =
     ARGP_COMMON_OPTIONS_WORKAROUND_FLAGS,
     ARGP_COMMON_SDR_CACHE_OPTIONS,
     ARGP_COMMON_SDR_CACHE_OPTIONS_FILE_DIRECTORY,
+    ARGP_COMMON_SDR_CACHE_OPTIONS_LEGACY,
     ARGP_COMMON_TIME_OPTIONS,
     ARGP_COMMON_HOSTRANGED_OPTIONS,
     ARGP_COMMON_OPTIONS_DEBUG,
@@ -167,7 +168,7 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
   int value;
 
   assert (state);
-  
+
   cmd_args = state->input;
 
   switch (key)
@@ -249,18 +250,18 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
     case GROUPS_KEY:            /* legacy */
     case SENSOR_TYPES_KEY:
       if (parse_sensor_types (SENSOR_PARSE_ALL_STRING,
-			      cmd_args->sensor_types,
-			      &(cmd_args->sensor_types_length),
-			      arg) < 0)
-	exit (EXIT_FAILURE);
+                              cmd_args->sensor_types,
+                              &(cmd_args->sensor_types_length),
+                              arg) < 0)
+        exit (EXIT_FAILURE);
       break;
     case EXCLUDE_GROUPS_KEY:    /* legacy */
     case EXCLUDE_SENSOR_TYPES_KEY:
       if (parse_sensor_types (SENSOR_PARSE_NONE_STRING,
-			      cmd_args->exclude_sensor_types,
-			      &(cmd_args->exclude_sensor_types_length),
-			      arg) < 0)
-	exit (EXIT_FAILURE);
+                              cmd_args->exclude_sensor_types,
+                              &(cmd_args->exclude_sensor_types_length),
+                              arg) < 0)
+        exit (EXIT_FAILURE);
       break;
     case LIST_GROUPS_KEY:       /* legacy */
     case LIST_SENSOR_TYPES_KEY:
