@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 /*****************************************************************************\
  *  $Id: ipmi-fru-parse-common.c,v 1.10 2010-02-08 22:09:40 chu11 Exp $
@@ -71,9 +71,9 @@
 
 int
 fru_dump_hex (ipmi_fru_ctx_t ctx,
-	      const void *frubuf,
-	      unsigned int length_in_bytes,
-	      const char *debug_hdr)
+              const void *frubuf,
+              unsigned int length_in_bytes,
+              const char *debug_hdr)
 {
   assert (ctx);
   assert (ctx->magic == IPMI_FRU_CTX_MAGIC);
@@ -83,11 +83,13 @@ fru_dump_hex (ipmi_fru_ctx_t ctx,
 
   if (ctx->flags & IPMI_FRU_FLAGS_DEBUG_DUMP)
     {
-      char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
+      char hdrbuf[DEBUG_UTIL_HDR_BUFLEN + 1];
+
+      memset (hdrbuf, '\0', DEBUG_UTIL_HDR_BUFLEN + 1);
 
       debug_hdr_str (DEBUG_UTIL_TYPE_NONE,
                      DEBUG_UTIL_DIRECTION_NONE,
-		     DEBUG_UTIL_FLAGS_DEFAULT,
+                     DEBUG_UTIL_FLAGS_DEFAULT,
                      debug_hdr,
                      hdrbuf,
                      DEBUG_UTIL_HDR_BUFLEN);
@@ -109,8 +111,8 @@ fru_dump_hex (ipmi_fru_ctx_t ctx,
 
 int
 fru_dump_obj (ipmi_fru_ctx_t ctx,
-	      fiid_obj_t obj,
-	      const char *debug_hdr)
+              fiid_obj_t obj,
+              const char *debug_hdr)
 {
   assert (ctx);
   assert (ctx->magic == IPMI_FRU_CTX_MAGIC);
@@ -119,11 +121,13 @@ fru_dump_obj (ipmi_fru_ctx_t ctx,
 
   if (ctx->flags & IPMI_FRU_FLAGS_DEBUG_DUMP)
     {
-      char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
+      char hdrbuf[DEBUG_UTIL_HDR_BUFLEN + 1];
+
+      memset (hdrbuf, '\0', DEBUG_UTIL_HDR_BUFLEN + 1);
 
       debug_hdr_str (DEBUG_UTIL_TYPE_NONE,
                      DEBUG_UTIL_DIRECTION_NONE,
-		     DEBUG_UTIL_FLAGS_DEFAULT,
+                     DEBUG_UTIL_FLAGS_DEFAULT,
                      debug_hdr,
                      hdrbuf,
                      DEBUG_UTIL_HDR_BUFLEN);
