@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,12 +52,13 @@
 
 #define IPMI_LAN_PKT_PAD_SIZE   1
 
+/* authentication code may contain plain password, always securely clear it */
 fiid_template_t tmpl_lan_session_hdr =
   {
     { 8, "authentication_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 32, "session_sequence_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 32, "session_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 128, "authentication_code", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_FIXED},
+    { 128, "authentication_code", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_SECURE_MEMSET_ON_CLEAR},
     { 8, "ipmi_msg_len", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 0, "", 0}
   };
@@ -258,7 +259,7 @@ assemble_ipmi_lan_pkt (fiid_obj_t obj_rmcp_hdr,
                        unsigned int authentication_code_data_len,
                        void *pkt,
                        unsigned int pkt_len,
-		       unsigned int flags)
+                       unsigned int flags)
 {
   uint8_t authentication_type;
   uint64_t val;
@@ -355,8 +356,6 @@ assemble_ipmi_lan_pkt (fiid_obj_t obj_rmcp_hdr,
       return (-1);
     }
 
-  memset (pkt, 0, pkt_len);
-
   if ((len = fiid_obj_get_all (obj_rmcp_hdr, pkt + indx, pkt_len - indx)) < 0)
     {
       FIID_OBJECT_ERROR_TO_ERRNO (obj_rmcp_hdr);
@@ -470,6 +469,7 @@ assemble_ipmi_lan_pkt (fiid_obj_t obj_rmcp_hdr,
     {
       int authentication_len;
 
+      /* clear out, might need empty buf */
       memset (pwbuf, '\0', IPMI_1_5_MAX_PASSWORD_LENGTH);
 
       if ((authentication_len = fiid_obj_field_len_bytes (obj_lan_session_hdr,
@@ -548,7 +548,6 @@ assemble_ipmi_lan_pkt (fiid_obj_t obj_rmcp_hdr,
                   md2_init (&ctx);
 
                   memcpy (authentication_code_field_ptr, digest, IPMI_1_5_MAX_PASSWORD_LENGTH);
-                  secure_memset (digest, '\0', MD2_DIGEST_LENGTH);
                 }
               else if (authentication_type == IPMI_AUTHENTICATION_TYPE_MD5)
                 {
@@ -567,7 +566,6 @@ assemble_ipmi_lan_pkt (fiid_obj_t obj_rmcp_hdr,
                   md5_init (&ctx);
 
                   memcpy (authentication_code_field_ptr, digest, IPMI_1_5_MAX_PASSWORD_LENGTH);
-                  secure_memset (digest, '\0', MD5_DIGEST_LENGTH);
                 }
             }
         }
@@ -582,8 +580,13 @@ assemble_ipmi_lan_pkt (fiid_obj_t obj_rmcp_hdr,
   rv = indx;
  cleanup:
   if (rv < 0)
-    secure_memset (pkt, '\0', pkt_len);
+    {
+      /* If plain password, pkt may contain it */
+      if (authentication_type == IPMI_AUTHENTICATION_TYPE_STRAIGHT_PASSWORD_KEY)
+        secure_memset (pkt, '\0', pkt_len);
+    }
   fiid_obj_destroy (obj_lan_msg_trlr);
+  /* secure_memset because can contain password */
   secure_memset (pwbuf, '\0', IPMI_1_5_MAX_PASSWORD_LENGTH);
   return (rv);
 }
@@ -611,7 +614,7 @@ unassemble_ipmi_lan_pkt (const void *pkt,
                          fiid_obj_t obj_lan_msg_hdr,
                          fiid_obj_t obj_cmd,
                          fiid_obj_t obj_lan_msg_trlr,
-			 unsigned int flags)
+                         unsigned int flags)
 {
   uint8_t authentication_type;
   unsigned int indx = 0;
@@ -671,7 +674,7 @@ unassemble_ipmi_lan_pkt (const void *pkt,
       FIID_OBJECT_ERROR_TO_ERRNO (obj_lan_msg_hdr);
       return (-1);
     }
-  
+
   if (fiid_obj_clear (obj_cmd) < 0)
     {
       FIID_OBJECT_ERROR_TO_ERRNO (obj_cmd);
@@ -811,7 +814,7 @@ unassemble_ipmi_lan_pkt (const void *pkt,
       return (-1);
     }
   indx += len;
-  
+
   if (FIID_OBJ_PACKET_VALID (obj_rmcp_hdr) == 1
       && FIID_OBJ_PACKET_VALID (obj_lan_session_hdr) == 1
       && FIID_OBJ_PACKET_VALID (obj_lan_msg_hdr) == 1
@@ -830,7 +833,7 @@ ipmi_lan_sendto (int s,
                  const struct sockaddr *to,
                  socklen_t tolen)
 {
-  /* achu: Specification table 13-8, indicates legacy padding for IPMI 1.5, but 
+  /* achu: Specification table 13-8, indicates legacy padding for IPMI 1.5, but
    * it appears it is specific to Ethernet 10/100 lan chips.
    *
    * It is so legacy at this point it is probably not worth providing.
@@ -840,7 +843,7 @@ ipmi_lan_sendto (int s,
    *
    * Why not just remove this function?  Leave just in case a legacy
    * pad situation pops up and we gotta implement something.
-   */ 
+   */
   return (ipmi_network_sendto (s, buf, len, flags, to, tolen));
 }
 
