@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,8 +134,6 @@ ipmi_calculate_sik (uint8_t authentication_algorithm,
 
   k_g_len = (k_g_len > IPMI_MAX_SIK_KEY_LENGTH) ? IPMI_MAX_SIK_KEY_LENGTH : k_g_len;
 
-  memset (hash_data, '\0', IPMI_MAX_KEY_DATA_LENGTH);
-
   /*
    * Build up data for hashing.
    */
@@ -167,13 +165,13 @@ ipmi_calculate_sik (uint8_t authentication_algorithm,
     }
 
   if ((computed_digest_len = crypt_hash (hash_algorithm,
-					 hash_flags,
-					 k_g,
-					 k_g_len,
-					 hash_data,
-					 hash_data_len,
-					 sik,
-					 sik_len)) < 0)
+                                         hash_flags,
+                                         k_g,
+                                         k_g_len,
+                                         hash_data,
+                                         hash_data_len,
+                                         sik,
+                                         sik_len)) < 0)
     {
       ERRNO_TRACE (errno);
       goto cleanup;
@@ -187,7 +185,6 @@ ipmi_calculate_sik (uint8_t authentication_algorithm,
 
   rv = computed_digest_len;
  cleanup:
-  secure_memset (hash_data, '\0', IPMI_MAX_KEY_DATA_LENGTH);
   return (rv);
 }
 
@@ -233,13 +230,13 @@ _calculate_k_rakp_hmac (unsigned int hash_algorithm,
    * with the constant 01h".
    */
   if ((computed_digest_len =  crypt_hash (hash_algorithm,
-					  IPMI_CRYPT_HASH_FLAGS_HMAC,
-					  sik_key,
-					  crypt_digest_len,
-					  constant,
-					  IPMI_KEY_CONSTANT_LENGTH,
-					  k,
-					  k_len)) < 0)
+                                          IPMI_CRYPT_HASH_FLAGS_HMAC,
+                                          sik_key,
+                                          crypt_digest_len,
+                                          constant,
+                                          IPMI_KEY_CONSTANT_LENGTH,
+                                          k,
+                                          k_len)) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
@@ -384,11 +381,11 @@ _ipmi_calculate_k (uint8_t authentication_algorithm,
                                         constant_len));
   else /* IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_SHA256 */
     return (_calculate_k_rakp_hmac_sha256 (sik_key,
-					   sik_key_len,
-					   k,
-					   k_len,
-					   constant,
-					   constant_len));
+                                           sik_key_len,
+                                           k,
+                                           k_len,
+                                           constant,
+                                           constant_len));
 }
 
 int
@@ -508,9 +505,9 @@ ipmi_calculate_rmcpplus_session_keys (uint8_t authentication_algorithm,
       sik_key_buf_len = 0;
     }
   else /*
-	 authentication_algorithm == IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_SHA1
-	 || authentication_algorithm == IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_MD5
-	 || authentication_algorithm == IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_SHA256
+         authentication_algorithm == IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_SHA1
+         || authentication_algorithm == IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_MD5
+         || authentication_algorithm == IPMI_AUTHENTICATION_ALGORITHM_RAKP_HMAC_SHA256
        */
     {
       if ((authentication_code_data_len && !authentication_code_data)
@@ -664,10 +661,8 @@ ipmi_calculate_rmcpplus_session_keys (uint8_t authentication_algorithm,
   *confidentiality_key_len = confidentiality_key_buf_len;
   rv = 0;
  cleanup:
+  /* secure_memset b/c k_g is a key */
   secure_memset (k_g_buf, '\0', IPMI_2_0_MAX_PASSWORD_LENGTH);
-  secure_memset (sik, '\0', IPMI_MAX_SIK_KEY_LENGTH);
-  secure_memset (k1, '\0', IPMI_MAX_K1_LENGTH);
-  secure_memset (k2, '\0', IPMI_MAX_K2_LENGTH);
   return (rv);
 }
 
@@ -758,7 +753,6 @@ ipmi_calculate_rakp_3_key_exchange_authentication_code (uint8_t authentication_a
     }
 
   /* checks above and memcpy limits below ensure can't overflow unsigned int */
-  memset (buf, '\0', IPMI_MAX_KEY_DATA_LENGTH);
   memcpy (buf + buf_index, managed_system_random_number, IPMI_MANAGED_SYSTEM_RANDOM_NUMBER_LENGTH);
   buf_index += IPMI_MANAGED_SYSTEM_RANDOM_NUMBER_LENGTH;
   buf[buf_index] = (remote_console_session_id & 0x000000ff);
@@ -796,13 +790,13 @@ ipmi_calculate_rakp_3_key_exchange_authentication_code (uint8_t authentication_a
     }
 
   if ((digest_len = crypt_hash (hash_algorithm,
-				hash_flags,
-				k_uid_ptr,
-				k_uid_ptr_len,
-				buf,
-				buf_index,
-				digest,
-				IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH)) < 0)
+                                hash_flags,
+                                k_uid_ptr,
+                                k_uid_ptr_len,
+                                buf,
+                                buf_index,
+                                digest,
+                                IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH)) < 0)
     {
       ERRNO_TRACE (errno);
       goto cleanup;
@@ -817,9 +811,6 @@ ipmi_calculate_rakp_3_key_exchange_authentication_code (uint8_t authentication_a
   memcpy (key_exchange_authentication_code, digest, digest_len);
   rv = digest_len;
  cleanup:
-  secure_memset (k_uid_buf, '\0', IPMI_2_0_MAX_PASSWORD_LENGTH);
-  secure_memset (buf, '\0', IPMI_MAX_KEY_DATA_LENGTH);
-  secure_memset (digest, '\0', IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH);
   return (rv);
 }
 
@@ -911,7 +902,6 @@ ipmi_rmcpplus_check_integrity_pad (fiid_obj_t obj_rmcpplus_session_trlr)
   if (pad_length > IPMI_INTEGRITY_PAD_MULTIPLE)
     return (0);
 
-  memset (integrity_pad, '\0', IPMI_MAX_INTEGRITY_PAD_LENGTH);
   if (fiid_obj_get_data (obj_rmcpplus_session_trlr,
                          "integrity_pad",
                          integrity_pad,
@@ -1035,7 +1025,6 @@ ipmi_rmcpplus_check_rakp_2_key_exchange_authentication_code (uint8_t authenticat
     }
 
   /* checks above and memcpy limits below ensure we can't overflow an unsigned int */
-  memset (buf, '\0', IPMI_MAX_KEY_DATA_LENGTH);
   buf[buf_index] = (remote_console_session_id & 0x000000ff);
   buf_index++;
   buf[buf_index] = (remote_console_session_id & 0x0000ff00) >> 8;
@@ -1085,13 +1074,13 @@ ipmi_rmcpplus_check_rakp_2_key_exchange_authentication_code (uint8_t authenticat
     }
 
   if ((digest_len = crypt_hash (hash_algorithm,
-				hash_flags,
-				k_uid_ptr,
-				k_uid_ptr_len,
-				buf,
-				buf_index,
-				digest,
-				IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH)) < 0)
+                                hash_flags,
+                                k_uid_ptr,
+                                k_uid_ptr_len,
+                                buf,
+                                buf_index,
+                                digest,
+                                IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH)) < 0)
     {
       ERRNO_TRACE (errno);
       goto cleanup;
@@ -1105,10 +1094,6 @@ ipmi_rmcpplus_check_rakp_2_key_exchange_authentication_code (uint8_t authenticat
 
   rv = memcmp (digest, key_exchange_authentication_code, digest_len) ? 0 : 1;
  cleanup:
-  secure_memset (k_uid_buf, '\0', IPMI_2_0_MAX_PASSWORD_LENGTH);
-  secure_memset (buf, '\0', IPMI_MAX_KEY_DATA_LENGTH);
-  secure_memset (digest, '\0', IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH);
-  secure_memset (key_exchange_authentication_code, '\0', IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH);
   return (rv);
 }
 
@@ -1215,7 +1200,6 @@ ipmi_rmcpplus_check_rakp_4_integrity_check_value (uint8_t authentication_algorit
     }
 
   /* checks above and memcpy limits below ensure can't overflow unsigned int */
-  memset (buf, '\0', IPMI_MAX_KEY_DATA_LENGTH);
   memcpy (buf + buf_index, remote_console_random_number, IPMI_REMOTE_CONSOLE_RANDOM_NUMBER_LENGTH);
   buf_index += IPMI_REMOTE_CONSOLE_RANDOM_NUMBER_LENGTH;
   buf[buf_index] = (managed_system_session_id & 0x000000ff);
@@ -1230,13 +1214,13 @@ ipmi_rmcpplus_check_rakp_4_integrity_check_value (uint8_t authentication_algorit
   buf_index += IPMI_MANAGED_SYSTEM_GUID_LENGTH;
 
   if ((digest_len = crypt_hash (hash_algorithm,
-				hash_flags,
-				sik_key,
-				sik_key_len,
-				buf,
-				buf_index,
-				digest,
-				IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH)) < 0)
+                                hash_flags,
+                                sik_key,
+                                sik_key_len,
+                                buf,
+                                buf_index,
+                                digest,
+                                IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH)) < 0)
     {
       ERRNO_TRACE (errno);
       goto cleanup;
@@ -1250,8 +1234,6 @@ ipmi_rmcpplus_check_rakp_4_integrity_check_value (uint8_t authentication_algorit
 
   rv = memcmp (digest, integrity_check_value, compare_len) ? 0 : 1;
  cleanup:
-  secure_memset (buf, '\0', IPMI_MAX_KEY_DATA_LENGTH);
-  secure_memset (digest, '\0', IPMI_MAX_KEY_EXCHANGE_AUTHENTICATION_CODE_LENGTH);
   return (rv);
 }
 
@@ -1266,7 +1248,7 @@ ipmi_rmcpplus_check_packet_session_authentication_code (uint8_t integrity_algori
                                                         fiid_obj_t obj_rmcpplus_session_trlr)
 {
   unsigned int hash_algorithm, hash_flags;
-  unsigned int expected_digest_len, compare_digest_len, hash_data_len;
+  unsigned int expected_digest_len, compare_digest_len, hash_data_len = 0;
   uint8_t hash_data[IPMI_MAX_PAYLOAD_LENGTH];
   uint8_t integrity_digest[IPMI_MAX_INTEGRITY_DATA_LENGTH];
   uint8_t authentication_code[IPMI_MAX_INTEGRITY_DATA_LENGTH];
@@ -1368,10 +1350,6 @@ ipmi_rmcpplus_check_packet_session_authentication_code (uint8_t integrity_algori
       goto cleanup;
     }
 
-  memset (hash_data, '\0', IPMI_MAX_PAYLOAD_LENGTH);
-
-  hash_data_len = 0;
-
   if (integrity_algorithm == IPMI_INTEGRITY_ALGORITHM_MD5_128)
     {
       /* achu: Password must be zero padded */
@@ -1398,13 +1376,13 @@ ipmi_rmcpplus_check_packet_session_authentication_code (uint8_t integrity_algori
     }
 
   if ((integrity_digest_len = crypt_hash (hash_algorithm,
-					  hash_flags,
-					  integrity_key,
-					  integrity_key_len,
-					  hash_data,
-					  hash_data_len,
-					  integrity_digest,
-					  IPMI_MAX_INTEGRITY_DATA_LENGTH)) < 0)
+                                          hash_flags,
+                                          integrity_key,
+                                          integrity_key_len,
+                                          hash_data,
+                                          hash_data_len,
+                                          integrity_digest,
+                                          IPMI_MAX_INTEGRITY_DATA_LENGTH)) < 0)
     {
       ERRNO_TRACE (errno);
       goto cleanup;
@@ -1418,8 +1396,10 @@ ipmi_rmcpplus_check_packet_session_authentication_code (uint8_t integrity_algori
 
   rv = memcmp (integrity_digest, authentication_code, compare_digest_len) ? 0 : 1;
  cleanup:
-  secure_memset (integrity_digest, '\0', IPMI_MAX_INTEGRITY_DATA_LENGTH);
-  secure_memset (authentication_code, '\0', IPMI_MAX_INTEGRITY_DATA_LENGTH);
+  /* secure_memset b/c contains password */
+  secure_memset (pwbuf, '\0', IPMI_2_0_MAX_PASSWORD_LENGTH);
+  /* secure_memset b/c contains password */
+  secure_memset (hash_data, '\0', hash_data_len);
   return (rv);
 }
 
